### Glossary


``` eval_rst
.. glossary::

    BAD
      The Book Analytics Dashboard Project (2022-2025) - a term used to refer to the Mellon Foundation funded project that is focused on creating a sustainable open access Book focused analytics service [1]_
    
    COKI
       Curtin Open Knowledge Initiative - a team of data scientists, software developers and researchers at Curtin University, Perth, Australia [2]_
       
    COUNTER
       COUNTER provides the standard that enables the knowledge community to count the use of electronic resources. To have their usage statistics and reports designated COUNTER compliant, report providers MUST provide usage statistics that conform to the current Code of Practice [3]_

    Crossref	
       Crossref is a Digital Object Identifier (DOI) Registration Agency of the International DOI Foundation, that makes metadata available for all DOIs registered with them [4]_

    dashboard	
       A dashboard is an interactive, up-to-date page of visualisations that aggregate and summarise data from different sources

    data source	
       A public or pilot project dashboard partner source of data about open access eBooks and their usage, such as views, downloads and online mentions
       
    eBook
      A book publication made available in electronic or digital form

    Google Books	
       Google Books provides paid and free (open access) eBooks [5]_
       
    IRUS
       IRUS – a service for capturing and processing institutional repository usage data, making it possible for institutional repositories and platforms to generate COUNTER compliant usage data [6]_
       
    IRUS Fulcrum 
    	Fulcrum is a “community-developed, open source platform for digital scholarship”. IRUS provides COUNTER standard usgae reports for eBooks hosted on the Fulcrum platform [7]_
     
    IRUS OAPEN
    	IRUS provides COUNTER standard usage reports for eBooks hosted on the OAPEN library and platform [8]_

    JSTOR	
       JSTOR is a digital library, which offers over 7000 open access eBooks [9]_
       
    Looker Studio
      A dashboarding solution provided by Google [10]_

    OAeBU	
       Open Access eBook Usage (2020 - 2022) - a term used to refer to the Mellon Foundation funded pilot project Developing a Pilot Data Trust for Open Access Ebook Usage  [11]_

    OAPEN	
       OAPEN is a not-for-profit organisation dedicated to open access, peer-reviewed books, operating three platforms: OAPEN Library; OAPEN Open Access Books Toolkit; and Directory of Open Access Books [12]_

    open access	
       Open access (OA) is free access to information, and unrestricted use of electronic resources for all [13]_

    ONIX	
       ONIX for Books (ONline Information eXchange) is a standard format that book publishers use to share information about the books that they have published [14]_

    SFTP	
       SSH File Transfer Protocol

    telescope	
       A telescope is a data workflow that fetches and ingests data from a data source. Some telescopes run workflows that process and output data to other places. Workflows are built on top of Apache Airflow's Directed Acyclic Graph (DAGs), where a DAG is “a collection of organized tasks that you want to schedule and run” [15]_ 
    
    the Dashboard
       Refers to the books analytics service operated by OAPEN [16]_
       

.. [1] https://openknowledge.community/projects/bad-project/

.. [2] https://openknowledge.community/

.. [3] https://www.projectcounter.org/

.. [4] https://www.crossref.org/community/

.. [5] https://play.google.com/books/publish/	

.. [6] https://www.jisc.ac.uk/irus

.. [7] https://www.fulcrum.org/

.. [8] https://www.oapen.org/

.. [9] https://about.jstor.org/librarians/books/open-access-books-jstor/	

.. [10] https://cloud.google.com/looker-studio

.. [11] https://educopia.org/data_trust/	

.. [12] https://www.oapen.org/oapen/1891940-organisation		

.. [13] https://en.unesco.org/open-access/what-open-access	

.. [14] https://bisg.org/general/custom.asp?page=ONIXforBooks

.. [15] https://cloud.google.com/composer/docs/run-apache-airflow-dag

.. [16] https://oapen.org/article/book-analytics-service